# -*- coding: utf-8 -*-

from django_six import re_path

from django_we import views as we_views


app_name = 'django_we'


# WeChat OAuth2
urlpatterns = [
    re_path(r'^o$', we_views.we_oauth2, name='shorten_o'),
    re_path(r'^oauth$', we_views.we_oauth2, name='shorten_oauth'),
    re_path(r'^oauth2$', we_views.we_oauth2, name='shorten_oauth2'),
    re_path(r'^we_oauth2$', we_views.we_oauth2, name='we_oauth2'),

    re_path(r'^br$', we_views.base_redirect, name='shorten_base_redirect'),
    re_path(r'^ur$', we_views.userinfo_redirect, name='shorten_userinfo_redirect'),
    re_path(r'^dbr$', we_views.direct_base_redirect, name='shorten_direct_base_redirect'),
    re_path(r'^dur$', we_views.direct_userinfo_redirect, name='shorten_direct_userinfo_redirect'),

    re_path(r'^base_redirect$', we_views.base_redirect, name='base_redirect'),
    re_path(r'^userinfo_redirect$', we_views.userinfo_redirect, name='userinfo_redirect'),
    re_path(r'^direct_base_redirect$', we_views.direct_base_redirect, name='direct_base_redirect'),
    re_path(r'^direct_userinfo_redirect$', we_views.direct_userinfo_redirect, name='direct_userinfo_redirect'),
]

# WeChat Share
urlpatterns += [
    re_path(r'^ws$', we_views.we_share, name='shorten_we_share'),
    re_path(r'^weshare$', we_views.we_share, name='we_share'),
]

# WeChat JSAPI Signature
urlpatterns += [
    re_path(r'^js/(?P<state>.*)$', we_views.we_jsapi_signature_api, name='shorten_we_jsapi_signature_api'),
    re_path(r'^jsapi_signature/(?P<state>.*)$', we_views.we_jsapi_signature_api, name='we_jsapi_signature_api'),
]

# WeChat Token
urlpatterns += [
    re_path(r'^token/(?P<state>.*)$', we_views.we_access_token, name='we_token'),
    re_path(r'^access_token/(?P<state>.*)$', we_views.we_access_token, name='we_access_token'),
]

# WeChat Callback
urlpatterns += [
    # 公众号（订阅号/服务号）
    # 服务器地址(URL)
    # 必须以http://或https://开头，分别支持80端口和443端口。
    re_path(r'^cb$', we_views.we_callback, name='shorten_we_callback'),
    re_path(r'^callback$', we_views.we_callback, name='we_callback'),
]

# WeChat Component Callback
urlpatterns += [
    # 第三方平台
    # 授权事件接收URL
    # 用于接收取消授权通知、授权成功通知、授权更新通知，也用于接收ticket，ticket是验证平台方的重要凭据。
    re_path(r'^ca$', we_views.we_component_auth, name='shorten_we_component_auth'),
    re_path(r'^component_auth$', we_views.we_component_auth, name='we_component_auth'),

    # 第三方平台
    # 消息与事件接收URL
    # 通过该URL接收公众号或小程序消息和事件推送，该参数按规则填写（需包含/$APPID$，如www.abc.com/$APPID$/callback），实际接收消息时$APPID$将被替换为公众号或小程序AppId。
    re_path(r'^cc/(?P<appid>.+)$', we_views.we_component_callback, name='shorten_we_component_callback'),
    re_path(r'^component_callback/(?P<appid>.+)$', we_views.we_component_callback, name='we_component_callback'),

    # https://open.weixin.qq.com/cgi-bin/showdocument?action=dir_list&t=resource/res_list&verify=1&id=open1453779503&token=&lang=zh_CN
    # 步骤4：授权后回调URI，得到授权码（authorization_code）和过期时间
    # 授权流程完成后，授权页会自动跳转进入回调URI，并在URL参数中返回授权码和过期时间(redirect_url?auth_code=xxx&expires_in=600)
    re_path(r'^cp$', we_views.we_component_preauth_callback, name='shorten_we_component_preauth_callback'),
    re_path(r'^component_preauth$', we_views.we_component_preauth_callback, name='we_component_preauth_callback'),
]

# WeChat Common/Component APIs
urlpatterns += [
    re_path(r'^qrurl/(?P<state>.*)$', we_views.we_qrcode_url, name='we_qrcode_url'),
]



# Generated by Django 2.2.15 on 2020-11-29 17:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_we', '0004_auto_20190820_1220'),
    ]

    operations = [
        migrations.AlterField(
            model_name='componentauthtokenrefreshloginfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='componenttokenrefreshloginfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='componentverifyticketloginfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='subscribeuserinfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='ticketrefreshloginfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='tokenrefreshloginfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.22 on 2019-08-19 08:40
from __future__ import unicode_literals

from django.db import migrations, models
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('django_we', '0002_componentverifyticketloginfo'),
    ]

    operations = [
        migrations.CreateModel(
            name='SubscribeUserInfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.BooleanField(db_index=True, default=True, help_text='Status', verbose_name='status')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Create Time', verbose_name='created_at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Update Time', verbose_name='updated_at')),
                ('unionid', models.CharField(blank=True, db_index=True, help_text='UnionID', max_length=32, null=True, verbose_name='unionid')),
                ('openid', models.CharField(blank=True, db_index=True, help_text='OpenID', max_length=32, null=True, verbose_name='openid')),
                ('nickname', models.CharField(blank=True, help_text='\u6635\u79f0', max_length=32, null=True, verbose_name='nickname')),
                ('sex', models.IntegerField(choices=[(0, '\u672a\u77e5'), (1, '\u7537'), (2, '\u5973')], db_index=True, default=0, help_text='\u6027\u522b', verbose_name='sex')),
                ('headimgurl', models.URLField(blank=True, help_text='\u5934\u50cf', null=True, verbose_name='headimgurl')),
                ('country', models.CharField(blank=True, help_text='\u56fd\u5bb6', max_length=16, null=True, verbose_name='country')),
                ('province', models.CharField(blank=True, help_text='\u7701\u4efd', max_length=16, null=True, verbose_name='province')),
                ('city', models.CharField(blank=True, help_text='\u57ce\u5e02', max_length=16, null=True, verbose_name='city')),
                ('subscribe', models.IntegerField(db_index=True, default=1, help_text='\u662f\u5426\u5173\u6ce8', verbose_name='subscribe')),
                ('subscribe_time', models.IntegerField(default=0, help_text='\u5173\u6ce8\u65f6\u95f4', verbose_name='subscribe_time')),
                ('subscribe_scene', models.CharField(blank=True, help_text='\u5173\u6ce8\u6e20\u9053\u6765\u6e90', max_length=32, null=True, verbose_name='subscribe_scene')),
                ('groupid', models.IntegerField(default=0, help_text='\u5206\u7ec4ID', verbose_name='groupid')),
                ('tagid_list', jsonfield.fields.JSONField(blank=True, help_text='\u6807\u7b7eID\u5217\u8868', null=True, verbose_name='tagid_list')),
                ('qr_scene', models.IntegerField(default=0, help_text='\u4e8c\u7ef4\u7801\u626b\u7801\u573a\u666f', verbose_name='qr_scene')),
                ('qr_scene_str', models.CharField(blank=True, help_text='\u4e8c\u7ef4\u7801\u626b\u7801\u573a\u666f\u63cf\u8ff0', max_length=64, null=True, verbose_name='qr_scene_str')),
                ('language', models.CharField(default='zh_CN', help_text='\u8bed\u8a00', max_length=8, verbose_name='language')),
                ('remark', models.CharField(blank=True, help_text='\u5907\u6ce8', max_length=16, null=True, verbose_name='remark')),
            ],
            options={
                'verbose_name': 'subscribeuserinfo',
                'verbose_name_plural': 'subscribeuserinfo',
            },
        ),
    ]



# -*- coding: utf-8 -*-

from functools import wraps

from django.conf import settings
from django.shortcuts import render


def wechat_only(func=None):
    def decorator(func):
        @wraps(func)
        def returned_wrapper(request, *args, **kwargs):
            if not settings.DEBUG and hasattr(request, 'wechat') and getattr(request, 'wechat'):
                if not (hasattr(request, 'WECHAT_ONLY') and not getattr(request, 'WECHAT_ONLY')):
                    return render(request, 'django_we/errmsg.html', {'title': '错误', 'errmsg': '请在微信中打开'})
            return func(request, *args, **kwargs)
        return returned_wrapper

    if not func:
        def foo(func):
            return decorator(func)
        return foo

    return decorator(func)



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import models
from django_models_ext import BaseModelMixin, SexModelMixin
from django_six import gettext_lazy as _
from jsonfield import JSONField


class TokenRefreshLogInfo(BaseModelMixin):
    appid = models.CharField(_(u'appid'), max_length=32, blank=True, null=True, help_text=u'APPID', db_index=True)
    secret = models.CharField(_(u'secret'), max_length=32, blank=True, null=True, help_text=u'Secret')
    access_info = JSONField(_(u'access_info'), blank=True, null=True, help_text=u'Access Info')

    class Meta:
        verbose_name = _(u'tokenrefreshloginfo')
        verbose_name_plural = _(u'tokenrefreshloginfo')

    def __unicode__(self):
        return self.pk


class TicketRefreshLogInfo(BaseModelMixin):
    appid = models.CharField(_(u'appid'), max_length=32, blank=True, null=True, help_text=u'APPID', db_index=True)
    secret = models.CharField(_(u'secret'), max_length=32, blank=True, null=True, help_text=u'Secret')
    ticket_type = models.CharField(_(u'ticket_type'), max_length=8, blank=True, null=True, help_text=u'Ticket Type')
    ticket_info = JSONField(_(u'ticket_info'), blank=True, null=True, help_text=u'Ticket Info')

    class Meta:
        verbose_name = _(u'ticketrefreshloginfo')
        verbose_name_plural = _(u'ticketrefreshloginfo')

    def __unicode__(self):
        return self.pk


class ComponentTokenRefreshLogInfo(BaseModelMixin):
    component_appid = models.CharField(_(u'component_appid'), max_length=32, blank=True, null=True, help_text=u'Component APPID', db_index=True)
    component_secret = models.CharField(_(u'component_secret'), max_length=32, blank=True, null=True, help_text=u'Component Secret')
    component_access_info = JSONField(_(u'component_access_info'), blank=True, null=True, help_text=u'Component Access Info')

    class Meta:
        verbose_name = _(u'componenttokenrefreshloginfo')
        verbose_name_plural = _(u'componenttokenrefreshloginfo')

    def __unicode__(self):
        return self.pk


class ComponentAuthTokenRefreshLogInfo(BaseModelMixin):
    component_appid = models.CharField(_(u'component_appid'), max_length=32, blank=True, null=True, help_text=u'Component APPID', db_index=True)
    component_secret = models.CharField(_(u'component_secret'), max_length=32, blank=True, null=True, help_text=u'Component Secret')
    authorizer_appid = models.CharField(_(u'authorizer_appid'), max_length=32, blank=True, null=True, help_text=u'Authorizer APPID', db_index=True)
    component_authorizer_access_info = JSONField(_(u'component_authorizer_access_info'), blank=True, null=True, help_text=u'Component Authorizer Access Info')

    class Meta:
        verbose_name = _(u'componentauthtokenrefreshloginfo')
        verbose_name_plural = _(u'componentauthtokenrefreshloginfo')

    def __unicode__(self):
        return self.pk


class ComponentVerifyTicketLogInfo(BaseModelMixin):
    component_appid = models.CharField(_(u'component_appid'), max_length=32, blank=True, null=True, help_text=u'Component APPID', db_index=True)
    component_secret = models.CharField(_(u'component_secret'), max_length=32, blank=True, null=True, help_text=u'Component Secret')
    component_verify_ticket = JSONField(_(u'component_verify_ticket'), blank=True, null=True, help_text=u'Component Verify Ticket')

    class Meta:
        verbose_name = _(u'componentverifyticketloginfo')
        verbose_name_plural = _(u'componentverifyticketloginfo')

    def __unicode__(self):
        return self.pk


class SubscribeUserInfo(BaseModelMixin):
    extraid = models.CharField(_(u'extraid'), max_length=32, blank=True, null=True, help_text=u'ExtraID', db_index=True)

    # Refer：https://mp.weixin.qq.com/wiki?t=resource/res_main&id=mp1421140839
    unionid = models.CharField(_(u'unionid'), max_length=32, blank=True, null=True, help_text=u'UnionID', db_index=True)
    openid = models.CharField(_(u'openid'), max_length=32, blank=True, null=True, help_text=u'OpenID', db_index=True)

    nickname = models.CharField(_(u'nickname'), max_length=32, blank=True, null=True, help_text=u'昵称')
    sex = models.IntegerField(_(u'sex'), choices=SexModelMixin.SEX_TUPLE, default=SexModelMixin.UNKNOWN, help_text=u'性别', db_index=True)
    headimgurl = models.URLField(_(u'headimgurl'), blank=True, null=True, help_text=u'头像')

    country = models.CharField(_(u'country'), max_length=16, blank=True, null=True, help_text=u'国家')
    province = models.CharField(_(u'province'), max_length=16, blank=True, null=True, help_text=u'省份')
    city = models.CharField(_(u'city'), max_length=16, blank=True, null=True, help_text=u'城市')

    subscribe = models.IntegerField(_(u'subscribe'), default=1, help_text=u'是否关注', db_index=True)
    subscribe_time = models.IntegerField(_(u'subscribe_time'), default=0, help_text=u'关注时间')
    subscribe_scene = models.CharField(_(u'subscribe_scene'), max_length=32, blank=True, null=True, help_text=u'关注渠道来源')

    groupid = models.IntegerField(_(u'groupid'), default=0, help_text=u'分组ID')
    tagid_list = JSONField(_(u'tagid_list'), blank=True, null=True, help_text=u'标签ID列表')

    qr_scene = models.IntegerField(_(u'qr_scene'), default=0, help_text=u'二维码扫码场景')
    qr_scene_str = models.CharField(_(u'qr_scene_str'), max_length=64, blank=True, null=True, help_text=u'二维码扫码场景描述')

    language = models.CharField(_(u'language'), max_length=8, default='zh_CN', help_text=u'语言')

    remark = models.CharField(_(u'remark'), max_length=16, blank=True, null=True, help_text=u'备注')

    class Meta:
        verbose_name = _(u'subscribeuserinfo')
        verbose_name_plural = _(u'subscribeuserinfo')

        unique_together = (
            ('extraid', 'unionid', 'openid'),
        )

    def __unicode__(self):
        return self.pk



# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib import admin
from django_admin import ReadOnlyModelAdmin

from django_we.models import (ComponentAuthTokenRefreshLogInfo, ComponentTokenRefreshLogInfo,
                              ComponentVerifyTicketLogInfo, SubscribeUserInfo, TicketRefreshLogInfo,
                              TokenRefreshLogInfo)


class TokenRefreshLogInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('appid', 'secret', 'access_info', 'status', 'created_at', 'updated_at')
    list_filter = ('appid', 'status')


class TicketRefreshLogInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('appid', 'secret', 'ticket_type', 'ticket_info', 'status', 'created_at', 'updated_at')
    list_filter = ('appid', 'ticket_type', 'status')


class ComponentTokenRefreshLogInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('component_appid', 'component_secret', 'component_access_info', 'status', 'created_at', 'updated_at')
    list_filter = ('component_appid', 'status')


class ComponentAuthTokenRefreshLogInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('component_appid', 'component_secret', 'authorizer_appid', 'component_authorizer_access_info', 'status', 'created_at', 'updated_at')
    list_filter = ('component_appid', 'authorizer_appid', 'status')


class ComponentVerifyTicketLogInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('component_appid', 'component_secret', 'component_verify_ticket', 'status', 'created_at', 'updated_at')
    list_filter = ('component_appid', 'status')


class SubscribeUserInfoAdmin(ReadOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('extraid', 'unionid', 'openid', 'nickname', 'sex', 'country', 'province', 'city', 'subscribe', 'subscribe_time', 'subscribe_scene', 'groupid', 'tagid_list', 'qr_scene', 'qr_scene_str', 'language', 'remark', 'status', 'created_at', 'updated_at')
    list_filter = ('extraid', 'sex', 'subscribe', 'subscribe_scene', 'language', 'status')
    search_fields = ('unionid', 'openid', 'nickname')


if not hasattr(settings, 'DJANGO_WE_MODEL_DISPLAY_OR_NOT') or getattr(settings, 'DJANGO_WE_MODEL_DISPLAY_OR_NOT'):
    admin.site.register(TokenRefreshLogInfo, TokenRefreshLogInfoAdmin)
    admin.site.register(TicketRefreshLogInfo, TicketRefreshLogInfoAdmin)
    admin.site.register(ComponentTokenRefreshLogInfo, ComponentTokenRefreshLogInfoAdmin)
    admin.site.register(ComponentAuthTokenRefreshLogInfo, ComponentAuthTokenRefreshLogInfoAdmin)
    admin.site.register(ComponentVerifyTicketLogInfo, ComponentVerifyTicketLogInfoAdmin)
    admin.site.register(SubscribeUserInfo, SubscribeUserInfoAdmin)
